summaryrefslogtreecommitdiffstats
path: root/kmail/kmfoldercachedimap.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfoldercachedimap.h')
-rw-r--r--kmail/kmfoldercachedimap.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmail/kmfoldercachedimap.h b/kmail/kmfoldercachedimap.h
index 21abeabf..61fcfcba 100644
--- a/kmail/kmfoldercachedimap.h
+++ b/kmail/kmfoldercachedimap.h
@@ -283,8 +283,8 @@ public:
void setACLList( const ACLList& arr );
// Reimplemented so the mStatusChangedLocally bool can be set
- virtual void setStatus( int id, KMMsgStatus status, bool toggle );
- virtual void setStatus( TQValueList<int>& ids, KMMsgStatus status, bool toggle );
+ virtual void seStatus( int id, KMMsgStatus status, bool toggle );
+ virtual void seStatus( TQValueList<int>& ids, KMMsgStatus status, bool toggle );
TQString annotationFolderType() const { return mAnnotationFolderType; }
@@ -588,7 +588,7 @@ private:
bool mSharedSeenFlagsChanged;
/**
* UIDs added by setStatus. Indicates that the client has changed
* the status of those mails. The mail flags for changed mails will be
* uploaded to the server, overwriting the server's notion of the status
* of the mails in this folder.
@@ -588,7 +588,7 @@ private:
bool mSharedSeenFlagsChanged;
/**
- * UIDs added by setStatus. Indicates that the client has changed
+ * UIDs added by seStatus. Indicates that the client has changed
* the status of those mails. The mail flags for changed mails will be
* uploaded to the server, overwriting the server's notion of the status